# p-asm

[![GPL-v3.0](https://img.shields.io/badge/license-GPL--3.0-orange)](https://spdx.org/licenses/GPL-3.0-or-later.html) [![PyPI - Python Version](https://img.shields.io/pypi/pyversions/p-asm-68000.svg)](https://python.org) [![PyPI - Version](https://img.shields.io/pypi/v/p-asm-68000.svg)](https://pypi.org/project/p-asm-68000)

A pre-assembler for 68000 code.

### Installation

**p-asm** is a pure Python project. It requires at least [Python](https://python.org) 3.8.

You can install **p-asm** by typing the following in a terminal window:

```console
pip install p-asm-68000
```

### License

**p-asm** is distributed under the terms of the [GPLv3.0](https://spdx.org/licenses/GPL-3.0-or-later.html) or later license.
